@@ -1,25 +1,25 @@
 # -*- coding: utf-8 -*-
-# Copyright 2007-2021 The HyperSpy developers
+# Copyright 2007-2022 The HyperSpy developers
 #
-# This file is part of  HyperSpy.
+# This file is part of HyperSpy.
 #
-#  HyperSpy is free software: you can redistribute it and/or modify
+# HyperSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-#  HyperSpy is distributed in the hope that it will be useful,
+# HyperSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with  HyperSpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with HyperSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
 import numpy as np
 import pytest
 
-from hyperspy.signals import Signal2D
+from hyperspy.signals import Signal1D, Signal2D
 from hyperspy.utils import roi
 
 BASELINE_DIR = 'plot_roi'
@@ -58,57 +58,70 @@ class TestPlotROI():
     @pytest.mark.mpl_image_compare(baseline_dir=BASELINE_DIR,
                                    tolerance=DEFAULT_TOL, style=STYLE_PYTEST_MPL)
     def test_plot_point1D_axis_0(self):
+        im = self.im
+        im.plot()
+        p = roi.Point1DROI(0.5)
+        p.add_widget(signal=im, axes=[0, ], color="cyan")
+        return im._plot.navigator_plot.figure
+
+    def test_plot_point1D_axis_0_non_iterable(self):
         self.im.plot()
         p = roi.Point1DROI(0.5)
-        p.add_widget(signal=self.im, axes=[0, ], color="cyan")
+        p.add_widget(signal=self.im, axes=0, color="cyan")
         return self.im._plot.navigator_plot.figure
 
     @pytest.mark.mpl_image_compare(baseline_dir=BASELINE_DIR,
                                    tolerance=DEFAULT_TOL, style=STYLE_PYTEST_MPL)
     def test_plot_point1D_axis_1(self):
-        self.im.plot()
+        im = self.im
+        im.plot()
         p = roi.Point1DROI(0.05)
-        p.add_widget(signal=self.im, axes=[1, ], color="cyan")
-        return self.im._plot.signal_plot.figure
+        p.add_widget(signal=im, axes=[1, ], color="cyan")
+        return im._plot.signal_plot.figure
 
     @pytest.mark.mpl_image_compare(baseline_dir=BASELINE_DIR,
                                    tolerance=DEFAULT_TOL, style=STYLE_PYTEST_MPL)
     def test_plot_point1D_axis_2(self):
-        self.im.plot()
+        im = self.im
+        im.plot()
         p = roi.Point1DROI(0.005)
-        p.add_widget(signal=self.im, axes=[2, ], color="cyan")
-        return self.im._plot.signal_plot.figure
+        p.add_widget(signal=im, axes=[2, ], color="cyan")
+        return im._plot.signal_plot.figure
 
     @pytest.mark.mpl_image_compare(baseline_dir=BASELINE_DIR,
                                    tolerance=DEFAULT_TOL, style=STYLE_PYTEST_MPL)
     def test_plot_spanroi_axis_0(self):
-        self.im.plot()
+        im = self.im
+        im.plot()
         p = roi.SpanROI(0.5, 0.7)
-        p.add_widget(signal=self.im, axes=[0, ], color="cyan")
-        return self.im._plot.navigator_plot.figure
+        p.add_widget(signal=im, axes=[0, ], color="cyan")
+        return im._plot.navigator_plot.figure
 
     def test_plot_spanroi_close(self):
-        self.im.plot()
+        im = self.im
+        im.plot()
         p = roi.SpanROI(0.5, 0.7)
-        p.add_widget(signal=self.im, axes=[0, ], color="cyan")
+        p.add_widget(signal=im, axes=[0, ], color="cyan")
         for widget in p.widgets:
             widget.close()
 
     @pytest.mark.mpl_image_compare(baseline_dir=BASELINE_DIR,
                                    tolerance=DEFAULT_TOL, style=STYLE_PYTEST_MPL)
     def test_plot_spanroi_axis_1(self):
-        self.im.plot()
+        im = self.im
+        im.plot()
         p = roi.SpanROI(0.05, 0.07)
-        p.add_widget(signal=self.im, axes=[1, ], color="cyan")
-        return self.im._plot.signal_plot.figure
+        p.add_widget(signal=im, axes=[1, ], color="cyan")
+        return im._plot.signal_plot.figure
 
     @pytest.mark.mpl_image_compare(baseline_dir=BASELINE_DIR,
                                    tolerance=DEFAULT_TOL, style=STYLE_PYTEST_MPL)
     def test_plot_spanroi_axis_2(self):
-        self.im.plot()
+        im = self.im
+        im.plot()
         p = roi.SpanROI(0.005, 0.007)
-        p.add_widget(signal=self.im, axes=[2, ], color="cyan")
-        return self.im._plot.signal_plot.figure
+        p.add_widget(signal=im, axes=[2, ], color="cyan")
+        return im._plot.signal_plot.figure
 
     @pytest.mark.parametrize("space", ("signal", "navigation"))
     @pytest.mark.mpl_image_compare(baseline_dir=BASELINE_DIR,
@@ -197,6 +210,19 @@ def test_error_message():
         p.add_widget(signal=im, axes=[0, ], color="cyan")
 
 
+def test_remove_rois():
+    s = Signal1D(np.arange(10))
+    s2 = s.deepcopy()
+    r = roi.SpanROI(2, 4)
+    s.plot()
+    s2.plot()
+
+    _ = r.interactive(s)
+    _ = r.interactive(s2)
+
+    r.remove_widget(s)
+
+
 @pytest.mark.parametrize('snap', [True, False])
 def test_snapping_axis_values(snap):
     s = Signal2D(np.arange(100).reshape(10, 10))
